## Build
* kernel: {{ build.metadata.kernel_version }}
* git: {{ build.metadata.git_repo }}
* git branch: {{ build.metadata.git_ref }}
* git commit: {{ build.metadata.git_sha }}
* git describe: {{ build.version }}
* test details: {{ build_url }}

